@@ -601,7 +601,8 @@ unmount_data_complete (UnmountData *data,
                        gboolean     complete_idle)
 {
   if (data->mount_operation &&
-      !unmount_operation_is_eject (data->mount_operation))
+      !unmount_operation_is_eject (data->mount_operation) &&
+      !unmount_operation_is_stop (data->mount_operation))
     gvfs_udisks2_unmount_notify_stop (data->mount_operation, data->failed);
 
   if (complete_idle)
@@ -692,7 +693,7 @@ on_mount_op_reply (GMountOperation       *mount_operation,
   data->reply_result = result;
   data->reply_choice = choice;
   data->reply_set = TRUE;
-  if (!data->completed || !data->in_progress)
+  if (!data->completed && !data->in_progress)
     mount_op_reply_handle (data);
 }
 
