@@ -28,9 +28,12 @@
 #include <gio/gio.h>
 
 static gboolean parent = FALSE;
+static gboolean show_version = FALSE;
+
 static GOptionEntry entries[] =
 {
   { "parent", 'p', 0, G_OPTION_ARG_NONE, &parent, N_("Create parent directories"), NULL },
+  { "version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Show program version"), NULL },
   { NULL }
 };
 
@@ -72,6 +75,12 @@ main (int argc, char *argv[])
       return 1;
     }
 
+  if (show_version)
+    {
+      g_print (PACKAGE_STRING "\n");
+      return 0;
+    }
+
   if (argc > 1)
     {
       int i;
