@@ -62,11 +62,13 @@ delete_trash_file (GFile *file, gboolean del_file, gboolean del_children)
 
 static gboolean force = FALSE;
 static gboolean empty = FALSE;
+static gboolean show_version = FALSE;
 
 static GOptionEntry entries[] =
 {
   { "force", 'f', 0, G_OPTION_ARG_NONE, &force, N_("Ignore nonexistent files, never prompt"), NULL },
   { "empty", 0, 0, G_OPTION_ARG_NONE, &empty, N_("Empty the trash"), NULL },
+  { "version", 0, 0, G_OPTION_ARG_NONE, &show_version, N_("Show program version"), NULL },
   { NULL }
 };
 
@@ -107,6 +109,12 @@ main (int argc, char *argv[])
       return 1;
     }
 
+  if (show_version)
+    {
+      g_print (PACKAGE_STRING "\n");
+      return 0;
+    }
+
   if (argc > 1)
     {
       int i;
